==> residualvm_0.2.1+dfsg.orig.tar.xz: residualvm-0.2.1/engines/myst3/gfx_opengl_texture.h <==
/* ResidualVM - A 3D game interpreter
 *
 * ResidualVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the AUTHORS
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 */

#ifndef GFX_OPENGL_TEXTURE_H
#define GFX_OPENGL_TEXTURE_H

#include "graphics/surface.h"
#include "graphics/opengles2/system_headers.h"
#include "common/textconsole.h"

#include "engines/myst3/gfx.h"

namespace Myst3 {

class OpenGLTexture : public Texture {
public:
	OpenGLTexture(const Graphics::Surface *surface, bool nonPoTSupport = false);
	virtual ~OpenGLTexture();

	void update(const Graphics::Surface *surface) override;

	GLuint id;
	GLuint internalFormat;
	GLuint sourceFormat;
	uint32 internalWidth;
	uint32 internalHeight;
};

} // End of namespace Myst3

#endif

==> residualvm_0.3.1+dfsg.orig.tar.xz: residualvm-0.3.1/engines/myst3/gfx_opengl_texture.h <==
/* ResidualVM - A 3D game interpreter
 *
 * ResidualVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the AUTHORS
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 */

#ifndef GFX_OPENGL_TEXTURE_H
#define GFX_OPENGL_TEXTURE_H

#include "graphics/surface.h"
#include "graphics/opengl/system_headers.h"
#include "common/textconsole.h"

#include "engines/myst3/gfx.h"

namespace Myst3 {

class OpenGLTexture : public Texture {
public:
	OpenGLTexture(const Graphics::Surface *surface);
	virtual ~OpenGLTexture();

	void update(const Graphics::Surface *surface) override;
	void updatePartial(const Graphics::Surface *surface, const Common::Rect &rect) override;

	GLuint id;
	GLuint internalFormat;
	GLuint sourceFormat;
	uint32 internalWidth;
	uint32 internalHeight;

private:
	void updateTexture(const Graphics::Surface *surface, const Common::Rect &rect);
};

} // End of namespace Myst3

#endif
